import { buildUUID } from '../../../utils/uuid';
import { ApiAction, ApiActionPage, QueryAble } from '../../model/baseModel';
import {
  CheckRuleListItem,
  CheckRulePageParams,
  CheckRulePageListGetResultModel,
  CheckRuleDtlParams,
  iBAS_CODE_DTL,
} from '../model/mesModel';
import { genAction, Api, genActionPage } from '../system';
import { defHttp } from '/@/utils/http/axios';
import { useUserStore } from '../../../store/modules/user';

/*
 * 获取规则分页列表
 */
export const getRuleListByPage = async (params: CheckRulePageParams) => {
  let sqlcmd = '';
  if (params?.RULE_CODE != undefined && params?.RULE_CODE != '') {
    sqlcmd += "And RULE_CODE like '%" + params?.RULE_CODE + "%'";
  }
  if (params?.RULE_NAME != undefined && params?.RULE_NAME != '') {
    sqlcmd += "And RULE_NAME like '%" + params?.RULE_NAME + "%'";
  }
  const rParams = genActionPage('BAS_CODE_RULE', sqlcmd, params.page, params.pageSize);
  return getRuleListByPageAsync(rParams);
};
async function getRuleListByPageAsync(params: ApiActionPage) {
  const data = await defHttp.post<ApiActionPage>(
    { url: Api.EntityPageList, params },
    {
      isTransformResponse: false,
    },
  );
  const model: CheckRulePageListGetResultModel = {
    items: data.Data.data,
    total: data.Data.totals,
    // items: data,
    // total: data.length,
  };
  return model;
}

/*
 * 获取规则明细列表
 */
export const getRuleDtl = async (params: CheckRuleDtlParams) => {
  let sqlcmd = '';
  if (params?.RULE_ID != undefined && params?.RULE_ID != '') {
    sqlcmd += "RULE_ID = '" + params?.RULE_ID + "'";
  }
  const rParams = genAction('BAS_CODE_DTL', { QueryAble_T:"", where: sqlcmd, order:'RULE_SEQ'});
  return getRuleDtlAsync(rParams);
};
async function getRuleDtlAsync(params: ApiAction<{}>) {
  const data = await defHttp.post<ApiAction<QueryAble>>(
    {
      url: Api.QueryUrl,
      params,
    },
    {
      errorMessageMode: 'modal',
      isTransformResponse: false,
    },
  );
  return data.Data;
}

/*
 * 根据ID获取规则
 */
export const getRuleById = async (params: CheckRuleDtlParams) => {
  let sqlcmd = '';
  if (params?.RULE_ID != undefined && params?.RULE_ID != '') {
    sqlcmd += "ID = '" + params?.RULE_ID + "'";
  }
  const rParams = genAction('BAS_CODE_RULE', { QueryAble_T:"", where: sqlcmd, order:''});
  return getRuleByIdAsync(rParams);
};
async function getRuleByIdAsync(params: ApiAction<{}>) {
  const data = await defHttp.post<ApiAction<QueryAble>>(
    {
      url: Api.QueryUrl,
      params,
    },
    {
      errorMessageMode: 'modal',
      isTransformResponse: false,
    },
  );
  return data.Data;
}

//保存
export const SaveRule = async (params: CheckRuleListItem) => {
  let data = await defHttp.post(
    { url: Api.SaveEntity, params: genAction('BAS_CODE_RULE', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};
export const SaveRuleDtl = async (params: iBAS_CODE_DTL[]) => {
  let data = await defHttp.post(
    { url: Api.SaveEntityList, params: genAction('BAS_CODE_DTL', params) },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
  return data;
};
//删除
export const DeleteRule = async (params: Recordable) => {
  const usParams = genAction('BAS_CODE_RULE', [params]);
  return await defHttp.post(
    { url: Api.DeleteList, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};
export const DeleteRuleDtl = async (RULE_ID: string) => {
  const usParams = genAction('BAS_CODE_DTL', `RULE_ID='${RULE_ID}'`);
  return await defHttp.post(
    { url: Api.DeleteWhere, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};
